If you would like to contribute to the development of OpenStack,
you must follow the steps documented at:

   http://docs.openstack.org/infra/manual/developers.html#getting-started

Once those steps have been completed, changes to OpenStack
should be submitted for review via the Gerrit tool, following
the workflow documented at:

   http://docs.openstack.org/infra/manual/developers.html#development-workflow

Pull requests submitted through GitHub will be ignored.

Bugs should be filed on Launchpad, not GitHub:

   https://bugs.launchpad.net/glance

Additionally, specific guidelines for contributing to Glance may be found in
Glance's Documentation:

   https://docs.openstack.org/glance/latest/contributor/index.html

Please read and follow these Glance-specific guidelines, particularly the
section on `Disallowed Minor Code Changes
<https://docs.openstack.org/glance/latest/contributor/minor-code-changes.html>`_.
You will thereby prevent your friendly review team from pulling out whatever
hair they have left. Thank you for your cooperation.
